==> undertow_2.2.5.orig.tar.gz: undertow-2.2.5.Final/websockets-jsr/src/test/java/io/undertow/websockets/jsr/test/reconnect/AnnotatedClientReconnectEndpoint.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2014 Red Hat, Inc., and individual contributors
 * as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package io.undertow.websockets.jsr.test.reconnect;

import javax.websocket.ClientEndpoint;
import javax.websocket.OnClose;
import javax.websocket.OnMessage;
import javax.websocket.OnOpen;
import java.util.concurrent.LinkedBlockingDeque;
import java.util.concurrent.TimeUnit;

/**
 * @author Stuart Douglas
 */
@ClientEndpoint
public class AnnotatedClientReconnectEndpoint {

    public static LinkedBlockingDeque<String> messages = new LinkedBlockingDeque<>();

    @OnOpen
    public void open() {
        messages.add("OPEN");
    }

    @OnClose
    public void close() {
        messages.add("CLOSE");
    }

    @OnMessage
    public void test(String message) {
        messages.add("MESSAGE-" + message);
    }

    public String message() {
        try {
            return messages.poll(10, TimeUnit.SECONDS);
        } catch (InterruptedException e) {
            throw new RuntimeException(e);
        }
    }
    public String quickMessage() {
        try {
            return messages.poll(500, TimeUnit.MICROSECONDS);
        } catch (InterruptedException e) {
            throw new RuntimeException(e);
        }
    }
}

==> undertow_2.3.8.orig.tar.gz: undertow-2.3.8.Final/websockets-jsr/src/test/java/io/undertow/websockets/jsr/test/reconnect/AnnotatedClientReconnectEndpoint.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2014 Red Hat, Inc., and individual contributors
 * as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package io.undertow.websockets.jsr.test.reconnect;

import jakarta.websocket.ClientEndpoint;
import jakarta.websocket.OnClose;
import jakarta.websocket.OnMessage;
import jakarta.websocket.OnOpen;
import java.util.concurrent.LinkedBlockingDeque;
import java.util.concurrent.TimeUnit;

/**
 * @author Stuart Douglas
 */
@ClientEndpoint
public class AnnotatedClientReconnectEndpoint {

    public static LinkedBlockingDeque<String> messages = new LinkedBlockingDeque<>();

    @OnOpen
    public void open() {
        messages.add("OPEN");
    }

    @OnClose
    public void close() {
        messages.add("CLOSE");
    }

    @OnMessage
    public void test(String message) {
        messages.add("MESSAGE-" + message);
    }

    public String message() {
        try {
            return messages.poll(10, TimeUnit.SECONDS);
        } catch (InterruptedException e) {
            throw new RuntimeException(e);
        }
    }
    public String quickMessage() {
        try {
            return messages.poll(500, TimeUnit.MICROSECONDS);
        } catch (InterruptedException e) {
            throw new RuntimeException(e);
        }
    }
}
